@@ -13,7 +13,11 @@
 #include "postgres.h"
 
 #include "access/sysattr.h"
+#if PG_VERSION_NUM >= 130000
+#include "access/detoast.h"
+#else
 #include "access/tuptoaster.h"
+#endif
 #include "catalog/pg_type.h"
 #include "libpq/pqformat.h"
 #include "nodes/parsenodes.h"
@@ -52,10 +56,12 @@ static void pglogical_read_tuple(StringInfo in, PGLogicalRelation *rel,
  */
 void
 pglogical_write_rel(StringInfo out, PGLogicalOutputData *data, Relation rel,
-					Bitmapset *att_list, const char *nsptarget, const char *reltarget)
+					Bitmapset *att_list)
 {
-	uint8		nsptargetlen;
-	uint8		reltargetlen;
+	char	   *nspname;
+	uint8		nspnamelen;
+	const char *relname;
+	uint8		relnamelen;
 	uint8		flags = 0;
 
 	pq_sendbyte(out, 'R');		/* sending RELATION */
@@ -66,16 +72,25 @@ pglogical_write_rel(StringInfo out, PGLogicalOutputData *data, Relation rel,
 	/* use Oid as relation identifier */
 	pq_sendint(out, RelationGetRelid(rel), 4);
 
-	nsptargetlen = strlen(nsptarget) + 1;
-	pq_sendbyte(out, nsptargetlen);		/* schema name length */
-	pq_sendbytes(out, nsptarget, nsptargetlen);
+	nspname = get_namespace_name(rel->rd_rel->relnamespace);
+	if (nspname == NULL)
+		elog(ERROR, "cache lookup failed for namespace %u",
+			 rel->rd_rel->relnamespace);
+	nspnamelen = strlen(nspname) + 1;
 
-	reltargetlen = strlen(reltarget) + 1;
-	pq_sendbyte(out, reltargetlen);		/* table name length */
-	pq_sendbytes(out, reltarget, reltargetlen);
+	relname = NameStr(rel->rd_rel->relname);
+	relnamelen = strlen(relname) + 1;
+
+	pq_sendbyte(out, nspnamelen);		/* schema name length */
+	pq_sendbytes(out, nspname, nspnamelen);
+
+	pq_sendbyte(out, relnamelen);		/* table name length */
+	pq_sendbytes(out, relname, relnamelen);
 
 	/* send the attribute info */
 	pglogical_write_attrs(out, rel, att_list);
+
+	pfree(nspname);
 }
 
 /*
